package org.obm.locator;

import java.io.IOException;
import java.util.Set;

import javax.servlet.ServletException;
import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.obm.locator.impl.LocatorDbHelper;

/**
 * Locates OBM host IP addresses with a service, service_property, login@domain.
 * This call url shoud be /location/host/sync/obm_sync/login@domain
 * 
 * @author tom
 * 
 */
public class HostLocationServlet extends HttpServlet {

	private static final long serialVersionUID = 1038700915530287492L;

	private Log logger = LogFactory.getLog(getClass());

	@Override
	protected void doGet(HttpServletRequest req, HttpServletResponse resp)
			throws ServletException, IOException {
		String query = req.getRequestURI();
		if (query.startsWith("/")) {
			query = query.substring(1);
		}
		String[] split = query.split("/");
		if (split.length != 5) {
			String errorMsg = "query should have 5 parts (got "
					+ split.length
					+ " parts "
					+ "(/location/host/sync/obm_sync/login@domain). The query was: "
					+ query;
			logger.error(errorMsg);
			resp.sendError(HttpServletResponse.SC_FORBIDDEN, errorMsg);
			return;
		}

		String service = split[2];
		String property = split[3];
		String loginAtDomain = split[4];

		Set<String> ips = LocatorDbHelper.findDomainHost(loginAtDomain,
				service, property);

		resp.setCharacterEncoding("utf-8");
		resp.setContentType("text/plain");

		StringBuilder returnedIps = new StringBuilder();
		returnedIps.append("[");
		if (ips.size() > 0) {
			StringBuilder sb = new StringBuilder();
			for (String ip : ips) {
				sb.append(ip);
				sb.append('\n');
				returnedIps.append(' ');
				returnedIps.append(ip);
			}
			returnedIps.append(" ]");
			byte[] b = sb.toString().getBytes();
			resp.setContentLength(b.length);
			ServletOutputStream out = resp.getOutputStream();
			out.write(b);
			out.close();
			if (logger.isInfoEnabled()) {
				logger.info("query: " + req.getRequestURI() + " => returned "
						+ ips.size() + " IP(s) address(es) "
						+ returnedIps.toString());
			}
		} else {
			String error = "Could not find " + service + "/" + property
					+ " for " + loginAtDomain;
			logger.error(error);
			resp.sendError(HttpServletResponse.SC_NOT_FOUND, error);
		}

	}

}
