package org.obm.locator;

import java.io.File;
import java.util.Hashtable;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.eclipse.core.runtime.Platform;
import org.eclipse.equinox.app.IApplication;
import org.eclipse.equinox.app.IApplicationContext;
import org.eclipse.equinox.http.jetty.JettyConfigurator;
import org.eclipse.equinox.http.jetty.JettyConstants;
import org.osgi.framework.Bundle;
import org.osgi.framework.BundleException;

public class LocatorService implements IApplication {

	Log logger = LogFactory.getLog(getClass());

	private static final String P12_PATH = "/etc/obm-locator/locator.p12";

	private static final int LOCATOR_PORT = 8084;

	@Override
	public Object start(IApplicationContext context) throws Exception {
		logger.info("Starting OBM Locator...");

		File sslP12 = new File(P12_PATH);
		if (!sslP12.exists()) {
			logger.error(P12_PATH + " not found. Exiting.");
			return 1;
		}

		Hashtable<String, Object> settings = new Hashtable<String, Object>();
		settings.put(JettyConstants.HTTP_ENABLED, false);
		settings.put(JettyConstants.CONTEXT_PATH, "");

		settings.put(JettyConstants.HTTPS_ENABLED, true);
		settings.put(JettyConstants.HTTPS_PORT, LOCATOR_PORT);
		settings.put(JettyConstants.SSL_KEYSTORETYPE, "PKCS12");
		settings.put(JettyConstants.SSL_KEYSTORE, sslP12.getAbsolutePath());
		settings.put(JettyConstants.SSL_PASSWORD, "password");
		settings.put(JettyConstants.SSL_KEYPASSWORD, "password");
		settings.put(JettyConstants.SSL_PROTOCOL, "SSL");
		settings.put(JettyConstants.SSL_WANTCLIENTAUTH, false);
		settings.put(JettyConstants.SSL_NEEDCLIENTAUTH, false);

		JettyConfigurator.startServer("obm-locator", settings);

		startBundle("org.eclipse.equinox.http.registry");

		logger.info("Accepting SSL queries on port " + LOCATOR_PORT);

		return IApplication.EXIT_OK;
	}

	@Override
	public void stop() {
		logger.info("OBM Locator stopped.");
	}

	private void startBundle(String bundleName) throws BundleException {
		Bundle bundle = Platform.getBundle(bundleName);
		if (bundle != null) {
			if (bundle.getState() == Bundle.RESOLVED) {
				bundle.start(Bundle.START_TRANSIENT);
			}
		}
	}
}
